Usage
=====

Before you can use django-livewatch, you have to install and configure it. Please see :ref:`installation` for more details.

To integrate ``django-livewatch`` with `livewatch.de <http://www.livewatch.de/>`_ you can use the following URLs:

* /livewatch/

... if you're using the cache extension:

* /livewatch/cache/

... if you're using the celery extension:

* /livewatch/celery/

... if you're using the rq extension:

* /livewatch/rq/
